import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData, setValidateFunc, createTypeMetaGuard } from "@kubernetes-models/base";
import { ValidateFunc } from "@kubernetes-models/validate";
import { validate } from "../../_schemas/AppthrustIoV1alpha1Project";

export interface IProject {
  "apiVersion": "appthrust.io/v1alpha1";
  "kind": "Project";
  "metadata"?: IObjectMeta;
  "spec": {
    "cdRef"?: {
      "name": string;
      "namespace"?: string;
    };
    "compositeDeletePolicy"?: "Background" | "Foreground";
    "compositionRef"?: {
      "name": string;
    };
    "compositionRevisionRef"?: {
      "name": string;
    };
    "compositionRevisionSelector"?: {
      "matchLabels": {
        [key: string]: string;
      };
    };
    "compositionSelector"?: {
      "matchLabels": {
        [key: string]: string;
      };
    };
    "compositionUpdatePolicy"?: "Automatic" | "Manual";
    "gitRepositoryRef"?: {
      "name": string;
      "namespace"?: string;
    };
    /**
     * The name of the project.
     */
    "name": string;
    "publishConnectionDetailsTo"?: {
      "configRef"?: {
        "name"?: string;
      };
      "metadata"?: {
        "annotations"?: {
          [key: string]: string;
        };
        "labels"?: {
          [key: string]: string;
        };
        "type"?: string;
      };
      "name": string;
    };
    "resourceRef"?: {
      "apiVersion": string;
      "kind": string;
      "name": string;
    };
    "writeConnectionSecretToRef"?: {
      "name": string;
    };
  };
  "status"?: {
    /**
     * Conditions of the resource.
     */
    "conditions"?: Array<{
      "lastTransitionTime": string;
      "message"?: string;
      "reason": string;
      "status": string;
      "type": string;
    }>;
    "connectionDetails"?: {
      "lastPublishedTime"?: string;
    };
  };
}

export class Project extends Model<IProject> implements IProject {
  "apiVersion": IProject["apiVersion"];
  "kind": IProject["kind"];
  "metadata"?: IProject["metadata"];
  "spec": IProject["spec"];
  "status"?: IProject["status"];

static apiVersion: IProject["apiVersion"] = "appthrust.io/v1alpha1";
static kind: IProject["kind"] = "Project";
static is = createTypeMetaGuard<IProject>(Project);

constructor(data?: ModelData<IProject>) {
  super({
    apiVersion: Project.apiVersion,
    kind: Project.kind,
    ...data
  } as IProject);
}
}


setValidateFunc(Project, validate as ValidateFunc<IProject>);
